@@ -78,7 +78,7 @@ impl Parser {
                 },
                 Some(Lexem::String(ref s)) | Some(Lexem::RawString(ref s)) | Some(Lexem::ArithmeticOperator(ref s)) => {
                     if s.to_ascii_lowercase() != "select" {
-                        if s == "*" && fields.is_empty() {
+                        if s == "*" {
                             #[cfg(unix)]
                                 {
                                     fields.push(Expr::field(Field::Mode));
@@ -87,6 +87,7 @@ impl Parser {
                                 }
 
                             fields.push(Expr::field(Field::Size));
+                            fields.push(Expr::field(Field::Modified));
                             fields.push(Expr::field(Field::Path));
                         } else {
                             self.drop_lexem();
@@ -762,4 +763,15 @@ mod tests {
 
         assert!(query.is_err());
     }
+
+    #[test]
+    fn path_with_spaces() {
+        let query = "select name from '/opt/Some Cool Dir/Test This'";
+        let mut p = Parser::new();
+        let query = p.parse(&query, false).unwrap();
+
+        assert_eq!(query.roots, vec![
+            Root::new(String::from("/opt/Some Cool Dir/Test This"), 0, 0, false, false, None, None, None, Bfs, false),
+        ]);
+    }
 }
